@@ -8,11 +8,11 @@
     :license: BSD, see LICENSE for more details.
 """
 
-__version__ = "0.5.1"
+__version__ = "0.5.2"
 
 import inspect
 from flask import Response, make_response
-import re
+import re, copy
 
 _temp_rule_cache = None
 
@@ -132,10 +132,9 @@ class FlaskView(object):
         """Extracts subdomain and endpoint values from the options dict and returns
            them along with a new dict without those values.
         """
-        subdomain = options.get("subdomain")
-        endpoint = options.get("endpoint")
-        options = {k:v for k,v in options.iteritems() if not k in ["subdomain", "endpoint"]}
-
+        options = copy.copy(options)
+        subdomain = options.pop('subdomain', None)
+        endpoint = options.pop('endpoint', None)
         return subdomain, endpoint, options,
 
 
